
jdsu-ocm
========

Netconf server and device driver for JDSU OCM 4-port TrueFlex C-band Optical
Channel Monitor.

The package consist of a device driver that runs over a serial port connection
as well as a netconf server and yang module for accessing the device.

Future improvements
-------------------

- Add SPI support.
- Add single port OCM support and extend yang.
